<?php

namespace Drupal\symfony_translation;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\StringTranslation\Translator\TranslatorInterface;
use Drupal\symfony_translation\Translator\TranslatorFactory;
use Symfony\Contracts\Translation\TranslatorInterface as SymfonyTranslatorInterface;

/**
 * String translator using the Symfony Translation component.
 */
class SymfonyTranslation implements TranslatorInterface {

  protected CacheBackendInterface $cache;
  protected SymfonyTranslatorInterface $translator;
  protected TranslatorFactory $translatorFactory;

  /**
   * Constructs a SymfonyTranslation object.
   *
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache
   *   The cache backend.
   * @param \Symfony\Contracts\Translation\TranslatorInterface $translator
   *   The translator.
   * @param \Drupal\symfony_translation\Translator\TranslatorFactory $translatorFactory
   *   The translator factory.
   */
  public function __construct(
    CacheBackendInterface $cache,
    SymfonyTranslatorInterface $translator,
    TranslatorFactory $translatorFactory
  ) {
    $this->cache = $cache;
    $this->translator = $translator;
    $this->translatorFactory = $translatorFactory;
  }

  /**
   * {@inheritdoc}
   */
  public function getStringTranslation($langcode, $string, $context) {
    $translation = $this->translator->trans($string, [], $context ?: NULL, $langcode);

    if ($translation === $string) {
      return FALSE;
    }

    return $translation;
  }

  /**
   * {@inheritdoc}
   */
  public function reset() {
    // Delete cached translation file paths.
    $this->cache->delete('symfony_translation.translation_files');

    // Delete cached catalogues.
    $cacheDir = $this->translatorFactory->getCacheDirectory();
    if (!file_exists($cacheDir)) {
      return;
    }

    $di = new \RecursiveDirectoryIterator($cacheDir, \FilesystemIterator::SKIP_DOTS);
    $ri = new \RecursiveIteratorIterator($di, \RecursiveIteratorIterator::CHILD_FIRST);

    foreach ($ri as $file) {
      $file->isDir() ? rmdir($file) : unlink($file);
    }
  }

}
